==> oci-2.42.0-py2.py3-none-any.whl: oci/log_analytics/models/field_summary_command_descriptor.py <==
# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_command_descriptor import AbstractCommandDescriptor
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FieldSummaryCommandDescriptor(AbstractCommandDescriptor):
    """
    Command descriptor for querylanguage FIELDSUMMARY command.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FieldSummaryCommandDescriptor object with values from keyword arguments. The default value of the :py:attr:`~oci.log_analytics.models.FieldSummaryCommandDescriptor.name` attribute
        of this class is ``FIELD_SUMMARY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this FieldSummaryCommandDescriptor.
            Allowed values for this property are: "COMMAND", "SEARCH", "STATS", "TIME_STATS", "SORT", "FIELDS", "ADD_FIELDS", "LINK", "LINK_DETAILS", "CLUSTER", "CLUSTER_DETAILS", "CLUSTER_SPLIT", "EVAL", "EXTRACT", "EVENT_STATS", "BUCKET", "CLASSIFY", "TOP", "BOTTOM", "HEAD", "TAIL", "FIELD_SUMMARY", "REGEX", "RENAME", "TIME_COMPARE", "WHERE", "CLUSTER_COMPARE", "DELETE", "DELTA", "DISTINCT", "SEARCH_LOOKUP", "LOOKUP", "DEMO_MODE", "MACRO", "MULTI_SEARCH", "HIGHLIGHT", "HIGHLIGHT_ROWS", "HIGHLIGHT_GROUPS", "CREATE_VIEW", "MAP", "NLP", "COMPARE"
        :type name: str

        :param display_query_string:
            The value to assign to the display_query_string property of this FieldSummaryCommandDescriptor.
        :type display_query_string: str

        :param internal_query_string:
            The value to assign to the internal_query_string property of this FieldSummaryCommandDescriptor.
        :type internal_query_string: str

        :param category:
            The value to assign to the category property of this FieldSummaryCommandDescriptor.
        :type category: str

        :param referenced_fields:
            The value to assign to the referenced_fields property of this FieldSummaryCommandDescriptor.
        :type referenced_fields: list[oci.log_analytics.models.AbstractField]

        :param declared_fields:
            The value to assign to the declared_fields property of this FieldSummaryCommandDescriptor.
        :type declared_fields: list[oci.log_analytics.models.AbstractField]

        :param max_values:
            The value to assign to the max_values property of this FieldSummaryCommandDescriptor.
        :type max_values: int

        """
        self.swagger_types = {
            'name': 'str',
            'display_query_string': 'str',
            'internal_query_string': 'str',
            'category': 'str',
            'referenced_fields': 'list[AbstractField]',
            'declared_fields': 'list[AbstractField]',
            'max_values': 'int'
        }

        self.attribute_map = {
            'name': 'name',
            'display_query_string': 'displayQueryString',
            'internal_query_string': 'internalQueryString',
            'category': 'category',
            'referenced_fields': 'referencedFields',
            'declared_fields': 'declaredFields',
            'max_values': 'maxValues'
        }

        self._name = None
        self._display_query_string = None
        self._internal_query_string = None
        self._category = None
        self._referenced_fields = None
        self._declared_fields = None
        self._max_values = None
        self._name = 'FIELD_SUMMARY'

    @property
    def max_values(self):
        """
        Gets the max_values of this FieldSummaryCommandDescriptor.
        Limit on number of distinct values to process for each field specified in the field summary command in the query string.


        :return: The max_values of this FieldSummaryCommandDescriptor.
        :rtype: int
        """
        return self._max_values

    @max_values.setter
    def max_values(self, max_values):
        """
        Sets the max_values of this FieldSummaryCommandDescriptor.
        Limit on number of distinct values to process for each field specified in the field summary command in the query string.


        :param max_values: The max_values of this FieldSummaryCommandDescriptor.
        :type: int
        """
        self._max_values = max_values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other

==> oci-2.60.0-py2.py3-none-any.whl: oci/log_analytics/models/field_summary_command_descriptor.py <==
# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_command_descriptor import AbstractCommandDescriptor
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FieldSummaryCommandDescriptor(AbstractCommandDescriptor):
    """
    Command descriptor for querylanguage FIELDSUMMARY command.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FieldSummaryCommandDescriptor object with values from keyword arguments. The default value of the :py:attr:`~oci.log_analytics.models.FieldSummaryCommandDescriptor.name` attribute
        of this class is ``FIELD_SUMMARY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this FieldSummaryCommandDescriptor.
            Allowed values for this property are: "COMMAND", "SEARCH", "STATS", "GEO_STATS", "TIME_STATS", "SORT", "FIELDS", "ADD_FIELDS", "LINK", "LINK_DETAILS", "CLUSTER", "CLUSTER_DETAILS", "CLUSTER_SPLIT", "EVAL", "EXTRACT", "JSON_EXTRACT", "XML_EXTRACT", "EVENT_STATS", "BUCKET", "CLASSIFY", "TOP", "BOTTOM", "HEAD", "TAIL", "FIELD_SUMMARY", "REGEX", "RENAME", "TIME_COMPARE", "WHERE", "CLUSTER_COMPARE", "DELETE", "DELTA", "DISTINCT", "SEARCH_LOOKUP", "LOOKUP", "DEMO_MODE", "MACRO", "MULTI_SEARCH", "HIGHLIGHT", "HIGHLIGHT_ROWS", "HIGHLIGHT_GROUPS", "CREATE_VIEW", "MAP", "NLP", "COMPARE"
        :type name: str

        :param display_query_string:
            The value to assign to the display_query_string property of this FieldSummaryCommandDescriptor.
        :type display_query_string: str

        :param internal_query_string:
            The value to assign to the internal_query_string property of this FieldSummaryCommandDescriptor.
        :type internal_query_string: str

        :param category:
            The value to assign to the category property of this FieldSummaryCommandDescriptor.
        :type category: str

        :param referenced_fields:
            The value to assign to the referenced_fields property of this FieldSummaryCommandDescriptor.
        :type referenced_fields: list[oci.log_analytics.models.AbstractField]

        :param declared_fields:
            The value to assign to the declared_fields property of this FieldSummaryCommandDescriptor.
        :type declared_fields: list[oci.log_analytics.models.AbstractField]

        :param max_values:
            The value to assign to the max_values property of this FieldSummaryCommandDescriptor.
        :type max_values: int

        """
        self.swagger_types = {
            'name': 'str',
            'display_query_string': 'str',
            'internal_query_string': 'str',
            'category': 'str',
            'referenced_fields': 'list[AbstractField]',
            'declared_fields': 'list[AbstractField]',
            'max_values': 'int'
        }

        self.attribute_map = {
            'name': 'name',
            'display_query_string': 'displayQueryString',
            'internal_query_string': 'internalQueryString',
            'category': 'category',
            'referenced_fields': 'referencedFields',
            'declared_fields': 'declaredFields',
            'max_values': 'maxValues'
        }

        self._name = None
        self._display_query_string = None
        self._internal_query_string = None
        self._category = None
        self._referenced_fields = None
        self._declared_fields = None
        self._max_values = None
        self._name = 'FIELD_SUMMARY'

    @property
    def max_values(self):
        """
        Gets the max_values of this FieldSummaryCommandDescriptor.
        Limit on number of distinct values to process for each field specified in the field summary command in the query string.


        :return: The max_values of this FieldSummaryCommandDescriptor.
        :rtype: int
        """
        return self._max_values

    @max_values.setter
    def max_values(self, max_values):
        """
        Sets the max_values of this FieldSummaryCommandDescriptor.
        Limit on number of distinct values to process for each field specified in the field summary command in the query string.


        :param max_values: The max_values of this FieldSummaryCommandDescriptor.
        :type: int
        """
        self._max_values = max_values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
